From 062875b88e20fd9dea45ddd120f20df6a307ba3e Mon Sep 17 00:00:00 2001
From: "jan.nijtmans" <nijtmans@users.sourceforge.net>
Date: Tue, 10 Nov 2020 14:51:44 +0000
Subject: Merge 9.0. Code/documentation cleanup

---
 .travis.yml                          |   2 +-
 doc/PkgRequire.3                     |   2 +-
 doc/StaticLibrary.3                  |  73 ++++++++
 doc/StaticPkg.3                      |  73 --------
 doc/load.n                           |  75 ++++----
 generic/tcl.decls                    |   4 +-
 generic/tcl.h                        |   3 +-
 generic/tclCmdIL.c                   |   2 +-
 generic/tclInt.decls                 |   2 +-
 generic/tclInt.h                     |   2 +-
 generic/tclIntDecls.h                |  16 +-
 generic/tclLoad.c                    | 354 +++++++++++++++++------------------
 generic/tclStubInit.c                |   6 +-
 generic/tclTest.c                    |  16 +-
 macosx/Tcl.xcode/project.pbxproj     |   4 +-
 macosx/Tcl.xcodeproj/project.pbxproj |   4 +-
 tests/load.test                      |  98 +++++-----
 tests/safe.test                      |   2 +-
 tests/unload.test                    |  22 +--
 unix/tclAppInit.c                    |   2 +-
 win/tcl.dsp                          |   2 +-
 win/tclAppInit.c                     |   6 +-
 22 files changed, 381 insertions(+), 389 deletions(-)
 create mode 100644 doc/StaticLibrary.3
 delete mode 100644 doc/StaticPkg.3

diff --git a/.travis.yml b/.travis.yml
index a7c1d2f..5c5ae80 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -243,7 +243,7 @@ jobs:
       script:
         - cmd.exe //C vcvarsall.bat x64 '&&' nmake 'OPTS=static,msvcrt' '-f' makefile.vc all tcltest
         - cmd.exe //C vcvarsall.bat x64 '&&' nmake 'OPTS=static,msvcrt' '-f' makefile.vc test
-    - name: "Windows/MSVC/StaticPackage"
+    - name: "Windows/MSVC/StaticPkg"
       os: windows
       compiler: cl
       env: *vcenv
diff --git a/doc/PkgRequire.3 b/doc/PkgRequire.3
index 71f3acf..f32c936 100644
--- a/doc/PkgRequire.3
+++ b/doc/PkgRequire.3
@@ -94,4 +94,4 @@ compatibility and translate their invocations to this form.
 .SH KEYWORDS
 package, present, provide, require, version
 .SH "SEE ALSO"
-package(n), Tcl_StaticPackage(3)
+package(n), Tcl_StaticLibrary(3)
diff --git a/doc/StaticLibrary.3 b/doc/StaticLibrary.3
new file mode 100644
index 0000000..ecd064c
--- /dev/null
+++ b/doc/StaticLibrary.3
@@ -0,0 +1,73 @@
+'\"
+'\" Copyright (c) 1995-1996 Sun Microsystems, Inc.
+'\"
+'\" See the file "license.terms" for information on usage and redistribution
+'\" of this file, and for a DISCLAIMER OF ALL WARRANTIES.
+'\"
+.TH Tcl_StaticLibrary 3 7.5 Tcl "Tcl Library Procedures"
+.so man.macros
+.BS
+.SH NAME
+Tcl_StaticLibrary \- make a statically linked package available via the 'load' command
+.SH SYNOPSIS
+.nf
+\fB#include <tcl.h>\fR
+.sp
+\fBTcl_StaticLibrary\fR(\fIinterp, pkgName, initProc, safeInitProc\fR)
+.SH ARGUMENTS
+.AS Tcl_PackageInitProc *safeInitProc
+.AP Tcl_Interp *interp in
+If not NULL, points to an interpreter into which the package has
+already been loaded (i.e., the caller has already invoked the
+appropriate initialization procedure).  NULL means the package
+has not yet been incorporated into any interpreter.
+.AP "const char" *pkgName in
+Name of the package;  should be properly capitalized (first letter
+upper-case, all others lower-case).
+.AP Tcl_PackageInitProc *initProc in
+Procedure to invoke to incorporate this package into a trusted
+interpreter.
+.AP Tcl_PackageInitProc *safeInitProc in
+Procedure to call to incorporate this package into a safe interpreter
+(one that will execute untrusted scripts).  NULL means the package
+cannot be used in safe interpreters.
+.BE
+.SH DESCRIPTION
+.PP
+This procedure may be invoked to announce that a package has been
+linked statically with a Tcl application and, optionally, that it
+has already been loaded into an interpreter.
+Once \fBTcl_StaticLibrary\fR has been invoked for a package, it
+may be loaded into interpreters using the \fBload\fR command.
+\fBTcl_StaticLibrary\fR is normally invoked only by the \fBTcl_AppInit\fR
+procedure for the application, not by packages for themselves
+(\fBTcl_StaticLibrary\fR should only be invoked for statically
+loaded packages, and code in the package itself should not need
+to know whether the package is dynamically or statically loaded).
+.PP
+When the \fBload\fR command is used later to load the package into
+an interpreter, one of \fIinitProc\fR and \fIsafeInitProc\fR will
+be invoked, depending on whether the target interpreter is safe
+or not.
+\fIinitProc\fR and \fIsafeInitProc\fR must both match the
+following prototype:
+.PP
+.CS
+typedef int \fBTcl_PackageInitProc\fR(
+        Tcl_Interp *\fIinterp\fR);
+.CE
+.PP
+The \fIinterp\fR argument identifies the interpreter in which the package
+is to be loaded.  The initialization procedure must return \fBTCL_OK\fR or
+\fBTCL_ERROR\fR to indicate whether or not it completed successfully; in
+the event of an error it should set the interpreter's result to point to an
+error message.  The result or error from the initialization procedure will
+be returned as the result of the \fBload\fR command that caused the
+initialization procedure to be invoked.
+.PP
+\fBTcl_StaticLibrary\fR can not be safely used by stub-enabled extensions,
+so its symbol is not included in the stub table.
+.SH KEYWORDS
+initialization procedure, package, static linking
+.SH "SEE ALSO"
+load(n), package(n), Tcl_PkgRequire(3)
diff --git a/doc/StaticPkg.3 b/doc/StaticPkg.3
deleted file mode 100644
index a28652e..0000000
--- a/doc/StaticPkg.3
+++ /dev/null
@@ -1,73 +0,0 @@
-'\"
-'\" Copyright (c) 1995-1996 Sun Microsystems, Inc.
-'\"
-'\" See the file "license.terms" for information on usage and redistribution
-'\" of this file, and for a DISCLAIMER OF ALL WARRANTIES.
-'\"
-.TH Tcl_StaticPackage 3 7.5 Tcl "Tcl Library Procedures"
-.so man.macros
-.BS
-.SH NAME
-Tcl_StaticPackage \- make a statically linked package available via the 'load' command
-.SH SYNOPSIS
-.nf
-\fB#include <tcl.h>\fR
-.sp
-\fBTcl_StaticPackage\fR(\fIinterp, pkgName, initProc, safeInitProc\fR)
-.SH ARGUMENTS
-.AS Tcl_PackageInitProc *safeInitProc
-.AP Tcl_Interp *interp in
-If not NULL, points to an interpreter into which the package has
-already been loaded (i.e., the caller has already invoked the
-appropriate initialization procedure).  NULL means the package
-has not yet been incorporated into any interpreter.
-.AP "const char" *pkgName in
-Name of the package;  should be properly capitalized (first letter
-upper-case, all others lower-case).
-.AP Tcl_PackageInitProc *initProc in
-Procedure to invoke to incorporate this package into a trusted
-interpreter.
-.AP Tcl_PackageInitProc *safeInitProc in
-Procedure to call to incorporate this package into a safe interpreter
-(one that will execute untrusted scripts).  NULL means the package
-cannot be used in safe interpreters.
-.BE
-.SH DESCRIPTION
-.PP
-This procedure may be invoked to announce that a package has been
-linked statically with a Tcl application and, optionally, that it
-has already been loaded into an interpreter.
-Once \fBTcl_StaticPackage\fR has been invoked for a package, it
-may be loaded into interpreters using the \fBload\fR command.
-\fBTcl_StaticPackage\fR is normally invoked only by the \fBTcl_AppInit\fR
-procedure for the application, not by packages for themselves
-(\fBTcl_StaticPackage\fR should only be invoked for statically
-loaded packages, and code in the package itself should not need
-to know whether the package is dynamically or statically loaded).
-.PP
-When the \fBload\fR command is used later to load the package into
-an interpreter, one of \fIinitProc\fR and \fIsafeInitProc\fR will
-be invoked, depending on whether the target interpreter is safe
-or not.
-\fIinitProc\fR and \fIsafeInitProc\fR must both match the
-following prototype:
-.PP
-.CS
-typedef int \fBTcl_PackageInitProc\fR(
-        Tcl_Interp *\fIinterp\fR);
-.CE
-.PP
-The \fIinterp\fR argument identifies the interpreter in which the package
-is to be loaded.  The initialization procedure must return \fBTCL_OK\fR or
-\fBTCL_ERROR\fR to indicate whether or not it completed successfully; in
-the event of an error it should set the interpreter's result to point to an
-error message.  The result or error from the initialization procedure will
-be returned as the result of the \fBload\fR command that caused the
-initialization procedure to be invoked.
-.PP
-\fBTcl_StaticPackage\fR can not be safely used by stub-enabled extensions,
-so its symbol is not included in the stub table.
-.SH KEYWORDS
-initialization procedure, package, static linking
-.SH "SEE ALSO"
-load(n), package(n), Tcl_PkgRequire(3)
diff --git a/doc/load.n b/doc/load.n
index 03b4f4e..b8a26ae 100644
--- a/doc/load.n
+++ b/doc/load.n
@@ -13,22 +13,21 @@ load \- Load machine code and initialize new commands
 .SH SYNOPSIS
 \fBload\fR ?\fB\-global\fR? ?\fB\-lazy\fR? ?\fB\-\-\fR? \fIfileName\fR
 .br
-\fBload\fR ?\fB\-global\fR? ?\fB\-lazy\fR? ?\fB\-\-\fR? \fIfileName packageName\fR
+\fBload\fR ?\fB\-global\fR? ?\fB\-lazy\fR? ?\fB\-\-\fR? \fIfileName prefix\fR
 .br
-\fBload\fR ?\fB\-global\fR? ?\fB\-lazy\fR? ?\fB\-\-\fR? \fIfileName packageName interp\fR
+\fBload\fR ?\fB\-global\fR? ?\fB\-lazy\fR? ?\fB\-\-\fR? \fIfileName prefix interp\fR
 .BE
 .SH DESCRIPTION
 .PP
 This command loads binary code from a file into the
 application's address space and calls an initialization procedure
-in the package to incorporate it into an interpreter.  \fIfileName\fR
+in the library to incorporate it into an interpreter.  \fIfileName\fR
 is the name of the file containing the code;  its exact form varies
 from system to system but on most systems it is a shared library,
 such as a \fB.so\fR file under Solaris or a DLL under Windows.
-\fIpackageName\fR is the name of the package, and is used to
-compute the name of an initialization procedure.
+\fIprefix\fR is used to compute the name of an initialization procedure.
 \fIinterp\fR is the path name of the interpreter into which to load
-the package (see the \fBinterp\fR manual entry for details);
+the library (see the \fBinterp\fR manual entry for details);
 if \fIinterp\fR is omitted, it defaults to the
 interpreter in which the \fBload\fR command was invoked.
 .PP
@@ -37,21 +36,19 @@ one of two initialization procedures will be invoked in the new code.
 Typically the initialization procedure will add new commands to a
 Tcl interpreter.
 The name of the initialization procedure is determined by
-\fIpackageName\fR and whether or not the target interpreter
+\fIprefix\fR and whether or not the target interpreter
 is a safe one.  For normal interpreters the name of the initialization
-procedure will have the form \fIpkg\fB_Init\fR, where \fIpkg\fR
-is the same as \fIpackageName\fR except that the first letter is
-converted to upper case and all other letters
-are converted to lower case.  For example, if \fIpackageName\fR is
-\fBfoo\fR or \fBFOo\fR, the initialization procedure's name will
+procedure will have the form \fIprefix\fB_Init\fR, where \fIprefix\fR
+is the same as \fIprefix\fR.  For example, if \fIprefix\fR is
+\fBFoo\fR, the initialization procedure's name will
 be \fBFoo_Init\fR.
 .PP
 If the target interpreter is a safe interpreter, then the name
-of the initialization procedure will be \fIpkg\fB_SafeInit\fR
-instead of \fIpkg\fB_Init\fR.
-The \fIpkg\fB_SafeInit\fR function should be written carefully, so that it
+of the initialization procedure will be \fIprefix\fB_SafeInit\fR
+instead of \fIprefix\fB_Init\fR.
+The \fIprefix\fB_SafeInit\fR function should be written carefully, so that it
 initializes the safe interpreter only with partial functionality provided
-by the package that is safe for use by untrusted code. For more information
+by the library that is safe for use by untrusted code. For more information
 on Safe\-Tcl, see the \fBsafe\fR manual entry.
 .PP
 The initialization procedure must match the following prototype:
@@ -62,7 +59,7 @@ typedef int \fBTcl_PackageInitProc\fR(
 .CE
 .PP
 The \fIinterp\fR argument identifies the interpreter in which the
-package is to be loaded.  The initialization procedure must return
+library is to be loaded.  The initialization procedure must return
 \fBTCL_OK\fR or \fBTCL_ERROR\fR to indicate whether or not it completed
 successfully;  in the event of an error it should set the interpreter's result
 to point to an error message.  The result of the \fBload\fR command
@@ -74,36 +71,34 @@ interpreters, then the first \fBload\fR will load the code and
 call the initialization procedure;  subsequent \fBload\fRs will
 call the initialization procedure without loading the code again.
 For Tcl versions lower than 8.5, it is not possible to unload or reload a
-package. From version 8.5 however, the \fBunload\fR command allows the unloading
+library. From version 8.5 however, the \fBunload\fR command allows the unloading
 of libraries loaded with \fBload\fR, for libraries that are aware of the
 Tcl's unloading mechanism.
 .PP
-The \fBload\fR command also supports packages that are statically
-linked with the application, if those packages have been registered
-by calling the \fBTcl_StaticPackage\fR procedure.
-If \fIfileName\fR is an empty string, then \fIpackageName\fR must
+The \fBload\fR command also supports libraries that are statically
+linked with the application, if those libraries have been registered
+by calling the \fBTcl_StaticLibrary\fR procedure.
+If \fIfileName\fR is an empty string, then \fIprefix\fR must
 be specified.
 .PP
-If \fIpackageName\fR is omitted or specified as an empty string,
-Tcl tries to guess the name of the package.
-This may be done differently on different platforms.
-The default guess, which is used on most UNIX platforms, is to
-take the last element of \fIfileName\fR, strip off the first
-three characters if they are \fBlib\fR, and use any following
-alphabetic and underline characters as the module name.
-For example, the command \fBload libxyz4.2.so\fR uses the module
-name \fBxyz\fR and the command \fBload bin/last.so {}\fR uses the
-module name \fBlast\fR.
-.PP
-If \fIfileName\fR is an empty string, then \fIpackageName\fR must
+If \fIprefix\fR is omitted or specified as an empty string,
+Tcl tries to guess the prefix by taking the last element of
+\fIfileName\fR, strip off the first three characters if they
+are \fBlib\fR, and use any following alphabetic and underline
+characters, converted to titlecase as the prefix.
+For example, the command \fBload libxyz4.2.so\fR uses the prefix
+\fBxyz\fR and the command \fBload bin/last.so {}\fR uses the
+prefix \fBlast\fR.
+.PP
+If \fIfileName\fR is an empty string, then \fIprefix\fR must
 be specified.
-The \fBload\fR command first searches for a statically loaded package
-(one that has been registered by calling the \fBTcl_StaticPackage\fR
+The \fBload\fR command first searches for a statically loaded library
+(one that has been registered by calling the \fBTcl_StaticLibrary\fR
 procedure) by that name; if one is found, it is used.
 Otherwise, the \fBload\fR command searches for a dynamically loaded
-package by that name, and uses it if it is found.  If several
+library by that name, and uses it if it is found.  If several
 different files have been \fBload\fRed with different versions of
-the package, Tcl picks the file that was loaded first.
+the library, Tcl picks the file that was loaded first.
 .PP
 If \fB\-global\fR is specified preceding the filename, all symbols
 found in the shared library are exported for global use by other
@@ -111,7 +106,7 @@ libraries. The option \fB\-lazy\fR delays the actual loading of
 symbols until their first actual use. The options may be abbreviated.
 The option \fB\-\-\fR indicates the end of the options, and should
 be used if you wish to use a filename which starts with \fB\-\fR
-and you provide a packageName to the \fBload\fR command.
+and you provide a prefix to the \fBload\fR command.
 .PP
 On platforms which do not support the \fB\-global\fR or \fB\-lazy\fR
 options, the options still exist but have no effect. Note that use
@@ -188,7 +183,7 @@ switch $tcl_platform(platform) {
 foo
 .CE
 .SH "SEE ALSO"
-info sharedlibextension, package(n), Tcl_StaticPackage(3), safe(n)
+info sharedlibextension, package(n), Tcl_StaticLibrary(3), safe(n)
 .SH KEYWORDS
 binary code, dynamic library, load, safe interpreter, shared library
 '\"Local Variables:
diff --git a/generic/tcl.decls b/generic/tcl.decls
index 4a58a20..ff97dfc 100644
--- a/generic/tcl.decls
+++ b/generic/tcl.decls
@@ -888,7 +888,7 @@ declare 243 {
 }
 # Removed in 9.0 (stub entry only)
 #declare 244  {
-#    void Tcl_StaticPackage(Tcl_Interp *interp, const char *pkgName,
+#    void Tcl_StaticLibrary(Tcl_Interp *interp, const char *prefix,
 #	    Tcl_PackageInitProc *initProc, Tcl_PackageInitProc *safeInitProc)
 #}
 # Removed in 9.0 (stub entry only)
@@ -2514,7 +2514,7 @@ export {
     Tcl_Interp *interp)
 }
 export {
-    void Tcl_StaticPackage(Tcl_Interp *interp, const char *pkgName,
+    void Tcl_StaticLibrary(Tcl_Interp *interp, const char *prefix,
 	    Tcl_PackageInitProc *initProc, Tcl_PackageInitProc *safeInitProc)
 }
 export {
diff --git a/generic/tcl.h b/generic/tcl.h
index eb6d2fe..a87c5d4 100644
--- a/generic/tcl.h
+++ b/generic/tcl.h
@@ -2189,10 +2189,11 @@ EXTERN void		Tcl_GetMemoryInfo(Tcl_DString *dsPtr);
 EXTERN void		Tcl_FindExecutable(const char *argv0);
 EXTERN void		Tcl_SetPanicProc(
 			    TCL_NORETURN1 Tcl_PanicProc *panicProc);
-EXTERN void		Tcl_StaticPackage(Tcl_Interp *interp,
+EXTERN void		Tcl_StaticLibrary(Tcl_Interp *interp,
 			    const char *pkgName,
 			    Tcl_PackageInitProc *initProc,
 			    Tcl_PackageInitProc *safeInitProc);
+#define Tcl_StaticPackage Tcl_StaticLibrary
 EXTERN Tcl_ExitProc *Tcl_SetExitProc(TCL_NORETURN1 Tcl_ExitProc *proc);
 #ifdef _WIN32
 EXTERN int		TclZipfs_AppHook(int *argc, wchar_t ***argv);
diff --git a/generic/tclCmdIL.c b/generic/tclCmdIL.c
index 5a8ef22..4536d18 100644
--- a/generic/tclCmdIL.c
+++ b/generic/tclCmdIL.c
@@ -1699,7 +1699,7 @@ InfoLoadedCmd(
     } else {			/* Get pkgs just in specified interp. */
 	packageName = TclGetString(objv[2]);
     }
-    return TclGetLoadedPackagesEx(interp, interpName, packageName);
+    return TclGetLoadedLibraries(interp, interpName, packageName);
 }
 
 /*
diff --git a/generic/tclInt.decls b/generic/tclInt.decls
index 5b02fb4..e764bc4 100644
--- a/generic/tclInt.decls
+++ b/generic/tclInt.decls
@@ -1058,7 +1058,7 @@ declare 256 {
 	    Tcl_Obj *part1Ptr, Tcl_Obj *part2Ptr, const int flags)
 }
 declare 257 {
-    void TclStaticPackage(Tcl_Interp *interp, const char *pkgName,
+    void TclStaticLibrary(Tcl_Interp *interp, const char *prefix,
 	    Tcl_PackageInitProc *initProc, Tcl_PackageInitProc *safeInitProc)
 }
 
diff --git a/generic/tclInt.h b/generic/tclInt.h
index 2a0dfa6..cd0f148 100644
--- a/generic/tclInt.h
+++ b/generic/tclInt.h
@@ -2975,7 +2975,7 @@ MODULE_SCOPE Tcl_Obj *	TclGetSourceFromFrame(CmdFrame *cfPtr, int objc,
 			    Tcl_Obj *const objv[]);
 MODULE_SCOPE char *	TclGetStringStorage(Tcl_Obj *objPtr,
 			    size_t *sizePtr);
-MODULE_SCOPE int	TclGetLoadedPackagesEx(Tcl_Interp *interp,
+MODULE_SCOPE int	TclGetLoadedLibraries(Tcl_Interp *interp,
 				const char *targetName,
 				const char *packageName);
 MODULE_SCOPE int	TclGetWideBitsFromObj(Tcl_Interp *, Tcl_Obj *,
diff --git a/generic/tclIntDecls.h b/generic/tclIntDecls.h
index e870aac..cf8d660 100644
--- a/generic/tclIntDecls.h
+++ b/generic/tclIntDecls.h
@@ -570,8 +570,8 @@ EXTERN int		TclPtrUnsetVar(Tcl_Interp *interp, Tcl_Var varPtr,
 				Tcl_Var arrayPtr, Tcl_Obj *part1Ptr,
 				Tcl_Obj *part2Ptr, const int flags);
 /* 257 */
-EXTERN void		TclStaticPackage(Tcl_Interp *interp,
-				const char *pkgName,
+EXTERN void		TclStaticLibrary(Tcl_Interp *interp,
+				const char *prefix,
 				Tcl_PackageInitProc *initProc,
 				Tcl_PackageInitProc *safeInitProc);
 /* 258 */
@@ -845,7 +845,7 @@ typedef struct TclIntStubs {
     Tcl_Obj * (*tclPtrIncrObjVar) (Tcl_Interp *interp, Tcl_Var varPtr, Tcl_Var arrayPtr, Tcl_Obj *part1Ptr, Tcl_Obj *part2Ptr, Tcl_Obj *incrPtr, const int flags); /* 254 */
     int (*tclPtrObjMakeUpvar) (Tcl_Interp *interp, Tcl_Var otherPtr, Tcl_Obj *myNamePtr, int myFlags); /* 255 */
     int (*tclPtrUnsetVar) (Tcl_Interp *interp, Tcl_Var varPtr, Tcl_Var arrayPtr, Tcl_Obj *part1Ptr, Tcl_Obj *part2Ptr, const int flags); /* 256 */
-    void (*tclStaticPackage) (Tcl_Interp *interp, const char *pkgName, Tcl_PackageInitProc *initProc, Tcl_PackageInitProc *safeInitProc); /* 257 */
+    void (*tclStaticLibrary) (Tcl_Interp *interp, const char *prefix, Tcl_PackageInitProc *initProc, Tcl_PackageInitProc *safeInitProc); /* 257 */
     Tcl_Obj * (*tclpCreateTemporaryDirectory) (Tcl_Obj *dirObj, Tcl_Obj *basenameObj); /* 258 */
     void (*tclAppendUnicodeToObj) (Tcl_Obj *objPtr, const Tcl_UniChar *unicode, size_t length); /* 259 */
     unsigned char * (*tclGetBytesFromObj) (Tcl_Interp *interp, Tcl_Obj *objPtr, size_t *lengthPtr); /* 260 */
@@ -1260,8 +1260,8 @@ extern const TclIntStubs *tclIntStubsPtr;
 	(tclIntStubsPtr->tclPtrObjMakeUpvar) /* 255 */
 #define TclPtrUnsetVar \
 	(tclIntStubsPtr->tclPtrUnsetVar) /* 256 */
-#define TclStaticPackage \
-	(tclIntStubsPtr->tclStaticPackage) /* 257 */
+#define TclStaticLibrary \
+	(tclIntStubsPtr->tclStaticLibrary) /* 257 */
 #define TclpCreateTemporaryDirectory \
 	(tclIntStubsPtr->tclpCreateTemporaryDirectory) /* 258 */
 #define TclAppendUnicodeToObj \
@@ -1274,9 +1274,9 @@ extern const TclIntStubs *tclIntStubsPtr;
 /* !END!: Do not edit above this line. */
 
 #if defined(USE_TCL_STUBS)
-#undef Tcl_StaticPackage
-#define Tcl_StaticPackage \
-	(tclIntStubsPtr->tclStaticPackage)
+#undef Tcl_StaticLibrary
+#define Tcl_StaticLibrary \
+	(tclIntStubsPtr->tclStaticLibrary)
 #endif /* defined(USE_TCL_STUBS) */
 
 #undef TCL_STORAGE_CLASS
diff --git a/generic/tclLoad.c b/generic/tclLoad.c
index 36c7457..67bc2cc 100644
--- a/generic/tclLoad.c
+++ b/generic/tclLoad.c
@@ -15,19 +15,17 @@
 /*
  * The following structure describes a package that has been loaded either
  * dynamically (with the "load" command) or statically (as indicated by a call
- * to TclGetLoadedPackages). All such packages are linked together into a
+ * to TclGetLoadedLibraries). All such packages are linked together into a
  * single list for the process. Packages are never unloaded, until the
  * application exits, when TclFinalizeLoad is called, and these structures are
  * freed.
  */
 
-typedef struct LoadedPackage {
+typedef struct LoadedLibrary {
     char *fileName;		/* Name of the file from which the package was
 				 * loaded. An empty string means the package
 				 * is loaded statically. Malloc-ed. */
-    char *packageName;		/* Name of package prefix for the package,
-				 * properly capitalized (first letter UC,
-				 * others LC), no "_", as in "Net".
+    char *prefix;		/* Prefix for the library.
 				 * Malloc-ed. */
     Tcl_LoadHandle loadHandle;	/* Token for the loaded file which should be
 				 * passed to (*unLoadProcPtr)() when the file
@@ -55,23 +53,23 @@ typedef struct LoadedPackage {
 				 * in trusted interpreters. */
     int safeInterpRefCount;	/* How many times the package has been loaded
 				 * in safe interpreters. */
-    struct LoadedPackage *nextPtr;
+    struct LoadedLibrary *nextPtr;
 				/* Next in list of all packages loaded into
 				 * this application process. NULL means end of
 				 * list. */
-} LoadedPackage;
+} LoadedLibrary;
 
 /*
  * TCL_THREADS
- * There is a global list of packages that is anchored at firstPackagePtr.
+ * There is a global list of packages that is anchored at firstLibraryPtr.
  * Access to this list is governed by a mutex.
  */
 
-static LoadedPackage *firstPackagePtr = NULL;
+static LoadedLibrary *firstLibraryPtr = NULL;
 				/* First in list of all packages loaded into
 				 * this process. */
 
-TCL_DECLARE_MUTEX(packageMutex)
+TCL_DECLARE_MUTEX(libraryMutex)
 
 /*
  * The following structure represents a particular package that has been
@@ -82,7 +80,7 @@ TCL_DECLARE_MUTEX(packageMutex)
  */
 
 typedef struct InterpPackage {
-    LoadedPackage *pkgPtr;	/* Points to detailed information about
+    LoadedLibrary *libraryPtr;	/* Points to detailed information about
 				 * package. */
     struct InterpPackage *nextPtr;
 				/* Next package in this interpreter, or NULL
@@ -121,14 +119,14 @@ Tcl_LoadObjCmd(
     Tcl_Obj *const objv[])	/* Argument objects. */
 {
     Tcl_Interp *target;
-    LoadedPackage *pkgPtr, *defaultPtr;
+    LoadedLibrary *libraryPtr, *defaultPtr;
     Tcl_DString pkgName, tmp, initName, safeInitName;
     Tcl_DString unloadName, safeUnloadName;
     InterpPackage *ipFirstPtr, *ipPtr;
     int code, namesMatch, filesMatch, offset;
     const char *symbols[2];
     Tcl_PackageInitProc *initProc;
-    const char *p, *fullFileName, *packageName;
+    const char *p, *fullFileName, *prefix;
     Tcl_LoadHandle loadHandle;
     Tcl_UniChar ch = 0;
     size_t len;
@@ -159,7 +157,7 @@ Tcl_LoadObjCmd(
 	}
     }
     if ((objc < 2) || (objc > 4)) {
-	Tcl_WrongNumArgs(interp, 1, savedobjv, "?-global? ?-lazy? ?--? fileName ?packageName? ?interp?");
+	Tcl_WrongNumArgs(interp, 1, savedobjv, "?-global? ?-lazy? ?--? fileName ?prefix? ?interp?");
 	return TCL_ERROR;
     }
     if (Tcl_FSConvertToPathType(interp, objv[1]) != TCL_OK) {
@@ -174,14 +172,14 @@ Tcl_LoadObjCmd(
     Tcl_DStringInit(&safeUnloadName);
     Tcl_DStringInit(&tmp);
 
-    packageName = NULL;
+    prefix = NULL;
     if (objc >= 3) {
-	packageName = TclGetString(objv[2]);
-	if (packageName[0] == '\0') {
-	    packageName = NULL;
+	prefix = TclGetString(objv[2]);
+	if (prefix[0] == '\0') {
+	    prefix = NULL;
 	}
     }
-    if ((fullFileName[0] == 0) && (packageName == NULL)) {
+    if ((fullFileName[0] == 0) && (prefix == NULL)) {
 	Tcl_SetObjResult(interp, Tcl_NewStringObj(
 		"must specify either file name or package name", -1));
 	Tcl_SetErrorCode(interp, "TCL", "OPERATION", "LOAD", "NOLIBRARY",
@@ -215,17 +213,17 @@ Tcl_LoadObjCmd(
      *	  only no statically loaded package with the same name.
      */
 
-    Tcl_MutexLock(&packageMutex);
+    Tcl_MutexLock(&libraryMutex);
 
     defaultPtr = NULL;
-    for (pkgPtr = firstPackagePtr; pkgPtr != NULL; pkgPtr = pkgPtr->nextPtr) {
-	if (packageName == NULL) {
+    for (libraryPtr = firstLibraryPtr; libraryPtr != NULL; libraryPtr = libraryPtr->nextPtr) {
+	if (prefix == NULL) {
 	    namesMatch = 0;
 	} else {
 	    TclDStringClear(&pkgName);
-	    Tcl_DStringAppend(&pkgName, packageName, -1);
+	    Tcl_DStringAppend(&pkgName, prefix, -1);
 	    TclDStringClear(&tmp);
-	    Tcl_DStringAppend(&tmp, pkgPtr->packageName, -1);
+	    Tcl_DStringAppend(&tmp, libraryPtr->prefix, -1);
 	    if (strcmp(Tcl_DStringValue(&tmp),
 		    Tcl_DStringValue(&pkgName)) == 0) {
 		namesMatch = 1;
@@ -235,12 +233,12 @@ Tcl_LoadObjCmd(
 	}
 	TclDStringClear(&pkgName);
 
-	filesMatch = (strcmp(pkgPtr->fileName, fullFileName) == 0);
-	if (filesMatch && (namesMatch || (packageName == NULL))) {
+	filesMatch = (strcmp(libraryPtr->fileName, fullFileName) == 0);
+	if (filesMatch && (namesMatch || (prefix == NULL))) {
 	    break;
 	}
 	if (namesMatch && (fullFileName[0] == 0)) {
-	    defaultPtr = pkgPtr;
+	    defaultPtr = libraryPtr;
 	}
 	if (filesMatch && !namesMatch && (fullFileName[0] != 0)) {
 	    /*
@@ -249,17 +247,17 @@ Tcl_LoadObjCmd(
 
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		    "file \"%s\" is already loaded for package \"%s\"",
-		    fullFileName, pkgPtr->packageName));
+		    fullFileName, libraryPtr->prefix));
 	    Tcl_SetErrorCode(interp, "TCL", "OPERATION", "LOAD",
 		    "SPLITPERSONALITY", NULL);
 	    code = TCL_ERROR;
-	    Tcl_MutexUnlock(&packageMutex);
+	    Tcl_MutexUnlock(&libraryMutex);
 	    goto done;
 	}
     }
-    Tcl_MutexUnlock(&packageMutex);
-    if (pkgPtr == NULL) {
-	pkgPtr = defaultPtr;
+    Tcl_MutexUnlock(&libraryMutex);
+    if (libraryPtr == NULL) {
+	libraryPtr = defaultPtr;
     }
 
     /*
@@ -268,17 +266,17 @@ Tcl_LoadObjCmd(
      * there's nothing for us to do.
      */
 
-    if (pkgPtr != NULL) {
+    if (libraryPtr != NULL) {
 	ipFirstPtr = (InterpPackage *)Tcl_GetAssocData(target, "tclLoad", NULL);
 	for (ipPtr = ipFirstPtr; ipPtr != NULL; ipPtr = ipPtr->nextPtr) {
-	    if (ipPtr->pkgPtr == pkgPtr) {
+	    if (ipPtr->libraryPtr == libraryPtr) {
 		code = TCL_OK;
 		goto done;
 	    }
 	}
     }
 
-    if (pkgPtr == NULL) {
+    if (libraryPtr == NULL) {
 	/*
 	 * The desired file isn't currently loaded, so load it. It's an error
 	 * if the desired package is a static one.
@@ -286,7 +284,7 @@ Tcl_LoadObjCmd(
 
 	if (fullFileName[0] == 0) {
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
-		    "package \"%s\" isn't loaded statically", packageName));
+		    "no library with prefix \"%s\" is loaded statically", prefix));
 	    Tcl_SetErrorCode(interp, "TCL", "OPERATION", "LOAD", "NOTSTATIC",
 		    NULL);
 	    code = TCL_ERROR;
@@ -297,8 +295,8 @@ Tcl_LoadObjCmd(
 	 * Figure out the module name if it wasn't provided explicitly.
 	 */
 
-	if (packageName != NULL) {
-	    Tcl_DStringAppend(&pkgName, packageName, -1);
+	if (prefix != NULL) {
+	    Tcl_DStringAppend(&pkgName, prefix, -1);
 	} else {
 	    Tcl_Obj *splitPtr, *pkgGuessPtr;
 	    int pElements;
@@ -389,10 +387,10 @@ Tcl_LoadObjCmd(
 	symbols[0] = Tcl_DStringValue(&initName);
 	symbols[1] = NULL;
 
-	Tcl_MutexLock(&packageMutex);
+	Tcl_MutexLock(&libraryMutex);
 	code = Tcl_LoadFile(interp, objv[1], symbols, flags, &initProc,
 		&loadHandle);
-	Tcl_MutexUnlock(&packageMutex);
+	Tcl_MutexUnlock(&libraryMutex);
 	if (code != TCL_OK) {
 	    goto done;
 	}
@@ -401,31 +399,31 @@ Tcl_LoadObjCmd(
 	 * Create a new record to describe this package.
 	 */
 
-	pkgPtr = (LoadedPackage *)Tcl_Alloc(sizeof(LoadedPackage));
+	libraryPtr = (LoadedLibrary *)Tcl_Alloc(sizeof(LoadedLibrary));
 	len = strlen(fullFileName) + 1;
-	pkgPtr->fileName	   = (char *)Tcl_Alloc(len);
-	memcpy(pkgPtr->fileName, fullFileName, len);
+	libraryPtr->fileName	   = (char *)Tcl_Alloc(len);
+	memcpy(libraryPtr->fileName, fullFileName, len);
 	len = Tcl_DStringLength(&pkgName) + 1;
-	pkgPtr->packageName	   = (char *)Tcl_Alloc(len);
-	memcpy(pkgPtr->packageName, Tcl_DStringValue(&pkgName), len);
-	pkgPtr->loadHandle	   = loadHandle;
-	pkgPtr->initProc	   = initProc;
-	pkgPtr->safeInitProc	   = (Tcl_PackageInitProc *)
+	libraryPtr->prefix	   = (char *)Tcl_Alloc(len);
+	memcpy(libraryPtr->prefix, Tcl_DStringValue(&pkgName), len);
+	libraryPtr->loadHandle	   = loadHandle;
+	libraryPtr->initProc	   = initProc;
+	libraryPtr->safeInitProc	   = (Tcl_PackageInitProc *)
 		Tcl_FindSymbol(interp, loadHandle,
 			Tcl_DStringValue(&safeInitName));
-	pkgPtr->unloadProc	   = (Tcl_PackageUnloadProc *)
+	libraryPtr->unloadProc	   = (Tcl_PackageUnloadProc *)
 		Tcl_FindSymbol(interp, loadHandle,
 			Tcl_DStringValue(&unloadName));
-	pkgPtr->safeUnloadProc	   = (Tcl_PackageUnloadProc *)
+	libraryPtr->safeUnloadProc	   = (Tcl_PackageUnloadProc *)
 		Tcl_FindSymbol(interp, loadHandle,
 			Tcl_DStringValue(&safeUnloadName));
-	pkgPtr->interpRefCount	   = 0;
-	pkgPtr->safeInterpRefCount = 0;
+	libraryPtr->interpRefCount	   = 0;
+	libraryPtr->safeInterpRefCount = 0;
 
-	Tcl_MutexLock(&packageMutex);
-	pkgPtr->nextPtr		   = firstPackagePtr;
-	firstPackagePtr		   = pkgPtr;
-	Tcl_MutexUnlock(&packageMutex);
+	Tcl_MutexLock(&libraryMutex);
+	libraryPtr->nextPtr		   = firstLibraryPtr;
+	firstLibraryPtr		   = libraryPtr;
+	Tcl_MutexUnlock(&libraryMutex);
 
 	/*
 	 * The Tcl_FindSymbol calls may have left a spurious error message in
@@ -441,27 +439,27 @@ Tcl_LoadObjCmd(
      */
 
     if (Tcl_IsSafe(target)) {
-	if (pkgPtr->safeInitProc == NULL) {
+	if (libraryPtr->safeInitProc == NULL) {
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		    "can't use package in a safe interpreter: no"
-		    " %s_SafeInit procedure", pkgPtr->packageName));
+		    " %s_SafeInit procedure", libraryPtr->prefix));
 	    Tcl_SetErrorCode(interp, "TCL", "OPERATION", "LOAD", "UNSAFE",
 		    NULL);
 	    code = TCL_ERROR;
 	    goto done;
 	}
-	code = pkgPtr->safeInitProc(target);
+	code = libraryPtr->safeInitProc(target);
     } else {
-	if (pkgPtr->initProc == NULL) {
+	if (libraryPtr->initProc == NULL) {
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		    "can't attach package to interpreter: no %s_Init procedure",
-		    pkgPtr->packageName));
+		    libraryPtr->prefix));
 	    Tcl_SetErrorCode(interp, "TCL", "OPERATION", "LOAD", "ENTRYPOINT",
 		    NULL);
 	    code = TCL_ERROR;
 	    goto done;
 	}
-	code = pkgPtr->initProc(target);
+	code = libraryPtr->initProc(target);
     }
 
     /*
@@ -492,13 +490,13 @@ Tcl_LoadObjCmd(
      * Update the proper reference count.
      */
 
-    Tcl_MutexLock(&packageMutex);
+    Tcl_MutexLock(&libraryMutex);
     if (Tcl_IsSafe(target)) {
-	pkgPtr->safeInterpRefCount++;
+	libraryPtr->safeInterpRefCount++;
     } else {
-	pkgPtr->interpRefCount++;
+	libraryPtr->interpRefCount++;
     }
-    Tcl_MutexUnlock(&packageMutex);
+    Tcl_MutexUnlock(&libraryMutex);
 
     /*
      * Refetch ipFirstPtr: loading the package may have introduced additional
@@ -507,7 +505,7 @@ Tcl_LoadObjCmd(
 
     ipFirstPtr = (InterpPackage *)Tcl_GetAssocData(target, "tclLoad", NULL);
     ipPtr = (InterpPackage *)Tcl_Alloc(sizeof(InterpPackage));
-    ipPtr->pkgPtr = pkgPtr;
+    ipPtr->libraryPtr = libraryPtr;
     ipPtr->nextPtr = ipFirstPtr;
     Tcl_SetAssocData(target, "tclLoad", LoadCleanupProc, ipPtr);
 
@@ -546,14 +544,14 @@ Tcl_UnloadObjCmd(
     Tcl_Obj *const objv[])	/* Argument objects. */
 {
     Tcl_Interp *target;		/* Which interpreter to unload from. */
-    LoadedPackage *pkgPtr, *defaultPtr;
+    LoadedLibrary *libraryPtr, *defaultPtr;
     Tcl_DString pkgName, tmp;
     Tcl_PackageUnloadProc *unloadProc;
     InterpPackage *ipFirstPtr, *ipPtr;
     int i, index, code, complain = 1, keepLibrary = 0;
     int trustedRefCount = -1, safeRefCount = -1;
     const char *fullFileName = "";
-    const char *packageName;
+    const char *prefix;
     static const char *const options[] = {
 	"-nocomplain", "-keeplibrary", "--", NULL
     };
@@ -597,7 +595,7 @@ Tcl_UnloadObjCmd(
   endOfForLoop:
     if ((objc-i < 1) || (objc-i > 3)) {
 	Tcl_WrongNumArgs(interp, 1, objv,
-		"?-switch ...? fileName ?packageName? ?interp?");
+		"?-switch ...? fileName ?prefix? ?interp?");
 	return TCL_ERROR;
     }
     if (Tcl_FSConvertToPathType(interp, objv[i]) != TCL_OK) {
@@ -608,14 +606,14 @@ Tcl_UnloadObjCmd(
     Tcl_DStringInit(&pkgName);
     Tcl_DStringInit(&tmp);
 
-    packageName = NULL;
+    prefix = NULL;
     if (objc - i >= 2) {
-	packageName = TclGetString(objv[i+1]);
-	if (packageName[0] == '\0') {
-	    packageName = NULL;
+	prefix = TclGetString(objv[i+1]);
+	if (prefix[0] == '\0') {
+	    prefix = NULL;
 	}
     }
-    if ((fullFileName[0] == 0) && (packageName == NULL)) {
+    if ((fullFileName[0] == 0) && (prefix == NULL)) {
 	Tcl_SetObjResult(interp, Tcl_NewStringObj(
 		"must specify either file name or package name", -1));
 	Tcl_SetErrorCode(interp, "TCL", "OPERATION", "UNLOAD", "NOLIBRARY",
@@ -648,19 +646,19 @@ Tcl_UnloadObjCmd(
      *	  only no statically loaded package with the same name.
      */
 
-    Tcl_MutexLock(&packageMutex);
+    Tcl_MutexLock(&libraryMutex);
 
     defaultPtr = NULL;
-    for (pkgPtr = firstPackagePtr; pkgPtr != NULL; pkgPtr = pkgPtr->nextPtr) {
+    for (libraryPtr = firstLibraryPtr; libraryPtr != NULL; libraryPtr = libraryPtr->nextPtr) {
 	int namesMatch, filesMatch;
 
-	if (packageName == NULL) {
+	if (prefix == NULL) {
 	    namesMatch = 0;
 	} else {
 	    TclDStringClear(&pkgName);
-	    Tcl_DStringAppend(&pkgName, packageName, -1);
+	    Tcl_DStringAppend(&pkgName, prefix, -1);
 	    TclDStringClear(&tmp);
-	    Tcl_DStringAppend(&tmp, pkgPtr->packageName, -1);
+	    Tcl_DStringAppend(&tmp, libraryPtr->prefix, -1);
 	    if (strcmp(Tcl_DStringValue(&tmp),
 		    Tcl_DStringValue(&pkgName)) == 0) {
 		namesMatch = 1;
@@ -670,32 +668,32 @@ Tcl_UnloadObjCmd(
 	}
 	TclDStringClear(&pkgName);
 
-	filesMatch = (strcmp(pkgPtr->fileName, fullFileName) == 0);
-	if (filesMatch && (namesMatch || (packageName == NULL))) {
+	filesMatch = (strcmp(libraryPtr->fileName, fullFileName) == 0);
+	if (filesMatch && (namesMatch || (prefix == NULL))) {
 	    break;
 	}
 	if (namesMatch && (fullFileName[0] == 0)) {
-	    defaultPtr = pkgPtr;
+	    defaultPtr = libraryPtr;
 	}
 	if (filesMatch && !namesMatch && (fullFileName[0] != 0)) {
 	    break;
 	}
     }
-    Tcl_MutexUnlock(&packageMutex);
+    Tcl_MutexUnlock(&libraryMutex);
     if (fullFileName[0] == 0) {
 	/*
 	 * It's an error to try unload a static package.
 	 */
 
 	Tcl_SetObjResult(interp, Tcl_ObjPrintf(
-		"package \"%s\" is loaded statically and cannot be unloaded",
-		packageName));
+		"library with prefix \"%s\" is loaded statically and cannot be unloaded",
+		prefix));
 	Tcl_SetErrorCode(interp, "TCL", "OPERATION", "UNLOAD", "STATIC",
 		NULL);
 	code = TCL_ERROR;
 	goto done;
     }
-    if (pkgPtr == NULL) {
+    if (libraryPtr == NULL) {
 	/*
 	 * The DLL pointed by the provided filename has never been loaded.
 	 */
@@ -715,10 +713,10 @@ Tcl_UnloadObjCmd(
      */
 
     code = TCL_ERROR;
-    if (pkgPtr != NULL) {
+    if (libraryPtr != NULL) {
 	ipFirstPtr = (InterpPackage *)Tcl_GetAssocData(target, "tclLoad", NULL);
 	for (ipPtr = ipFirstPtr; ipPtr != NULL; ipPtr = ipPtr->nextPtr) {
-	    if (ipPtr->pkgPtr == pkgPtr) {
+	    if (ipPtr->libraryPtr == libraryPtr) {
 		code = TCL_OK;
 		break;
 	    }
@@ -740,12 +738,12 @@ Tcl_UnloadObjCmd(
 
     /*
      * Ensure that the DLL can be unloaded. If it is a trusted interpreter,
-     * pkgPtr->unloadProc must not be NULL for the DLL to be unloadable. If
-     * the interpreter is a safe one, pkgPtr->safeUnloadProc must be non-NULL.
+     * libraryPtr->unloadProc must not be NULL for the DLL to be unloadable. If
+     * the interpreter is a safe one, libraryPtr->safeUnloadProc must be non-NULL.
      */
 
     if (Tcl_IsSafe(target)) {
-	if (pkgPtr->safeUnloadProc == NULL) {
+	if (libraryPtr->safeUnloadProc == NULL) {
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		    "file \"%s\" cannot be unloaded under a safe interpreter",
 		    fullFileName));
@@ -754,9 +752,9 @@ Tcl_UnloadObjCmd(
 	    code = TCL_ERROR;
 	    goto done;
 	}
-	unloadProc = pkgPtr->safeUnloadProc;
+	unloadProc = libraryPtr->safeUnloadProc;
     } else {
-	if (pkgPtr->unloadProc == NULL) {
+	if (libraryPtr->unloadProc == NULL) {
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
 		    "file \"%s\" cannot be unloaded under a trusted interpreter",
 		    fullFileName));
@@ -765,7 +763,7 @@ Tcl_UnloadObjCmd(
 	    code = TCL_ERROR;
 	    goto done;
 	}
-	unloadProc = pkgPtr->unloadProc;
+	unloadProc = libraryPtr->unloadProc;
     }
 
     /*
@@ -780,10 +778,10 @@ Tcl_UnloadObjCmd(
 
     code = TCL_UNLOAD_DETACH_FROM_INTERPRETER;
     if (!keepLibrary) {
-	Tcl_MutexLock(&packageMutex);
-	trustedRefCount = pkgPtr->interpRefCount;
-	safeRefCount = pkgPtr->safeInterpRefCount;
-	Tcl_MutexUnlock(&packageMutex);
+	Tcl_MutexLock(&libraryMutex);
+	trustedRefCount = libraryPtr->interpRefCount;
+	safeRefCount = libraryPtr->safeInterpRefCount;
+	Tcl_MutexUnlock(&libraryMutex);
 
 	if (Tcl_IsSafe(target)) {
 	    safeRefCount--;
@@ -806,34 +804,34 @@ Tcl_UnloadObjCmd(
      * if we unload the DLL.
      */
 
-    Tcl_MutexLock(&packageMutex);
+    Tcl_MutexLock(&libraryMutex);
     if (Tcl_IsSafe(target)) {
-	pkgPtr->safeInterpRefCount--;
+	libraryPtr->safeInterpRefCount--;
 
 	/*
 	 * Do not let counter get negative.
 	 */
 
-	if (pkgPtr->safeInterpRefCount < 0) {
-	    pkgPtr->safeInterpRefCount = 0;
+	if (libraryPtr->safeInterpRefCount < 0) {
+	    libraryPtr->safeInterpRefCount = 0;
 	}
     } else {
-	pkgPtr->interpRefCount--;
+	libraryPtr->interpRefCount--;
 
 	/*
 	 * Do not let counter get negative.
 	 */
 
-	if (pkgPtr->interpRefCount < 0) {
-	    pkgPtr->interpRefCount = 0;
+	if (libraryPtr->interpRefCount < 0) {
+	    libraryPtr->interpRefCount = 0;
 	}
     }
-    trustedRefCount = pkgPtr->interpRefCount;
-    safeRefCount = pkgPtr->safeInterpRefCount;
-    Tcl_MutexUnlock(&packageMutex);
+    trustedRefCount = libraryPtr->interpRefCount;
+    safeRefCount = libraryPtr->safeInterpRefCount;
+    Tcl_MutexUnlock(&libraryMutex);
 
     code = TCL_OK;
-    if (pkgPtr->safeInterpRefCount <= 0 && pkgPtr->interpRefCount <= 0
+    if (libraryPtr->safeInterpRefCount <= 0 && libraryPtr->interpRefCount <= 0
 	    && !keepLibrary) {
 	/*
 	 * Unload the shared library from the application memory...
@@ -847,21 +845,21 @@ Tcl_UnloadObjCmd(
 	 * it's been unloaded.
 	 */
 
-	if (pkgPtr->fileName[0] != '\0') {
-	    Tcl_MutexLock(&packageMutex);
-	    if (Tcl_FSUnloadFile(interp, pkgPtr->loadHandle) == TCL_OK) {
+	if (libraryPtr->fileName[0] != '\0') {
+	    Tcl_MutexLock(&libraryMutex);
+	    if (Tcl_FSUnloadFile(interp, libraryPtr->loadHandle) == TCL_OK) {
 		/*
 		 * Remove this library from the loaded library cache.
 		 */
 
-		defaultPtr = pkgPtr;
-		if (defaultPtr == firstPackagePtr) {
-		    firstPackagePtr = pkgPtr->nextPtr;
+		defaultPtr = libraryPtr;
+		if (defaultPtr == firstLibraryPtr) {
+		    firstLibraryPtr = libraryPtr->nextPtr;
 		} else {
-		    for (pkgPtr = firstPackagePtr; pkgPtr != NULL;
-			    pkgPtr = pkgPtr->nextPtr) {
-			if (pkgPtr->nextPtr == defaultPtr) {
-			    pkgPtr->nextPtr = defaultPtr->nextPtr;
+		    for (libraryPtr = firstLibraryPtr; libraryPtr != NULL;
+			    libraryPtr = libraryPtr->nextPtr) {
+			if (libraryPtr->nextPtr == defaultPtr) {
+			    libraryPtr->nextPtr = defaultPtr->nextPtr;
 			    break;
 			}
 		    }
@@ -873,14 +871,14 @@ Tcl_UnloadObjCmd(
 
 		ipFirstPtr = (InterpPackage *)Tcl_GetAssocData(target, "tclLoad", NULL);
 		ipPtr = ipFirstPtr;
-		if (ipPtr->pkgPtr == defaultPtr) {
+		if (ipPtr->libraryPtr == defaultPtr) {
 		    ipFirstPtr = ipFirstPtr->nextPtr;
 		} else {
 		    InterpPackage *ipPrevPtr;
 
 		    for (ipPrevPtr = ipPtr; ipPtr != NULL;
 			    ipPrevPtr = ipPtr, ipPtr = ipPtr->nextPtr) {
-			if (ipPtr->pkgPtr == defaultPtr) {
+			if (ipPtr->libraryPtr == defaultPtr) {
 			    ipPrevPtr->nextPtr = ipPtr->nextPtr;
 			    break;
 			}
@@ -889,10 +887,10 @@ Tcl_UnloadObjCmd(
 		Tcl_SetAssocData(target, "tclLoad", LoadCleanupProc,
 			ipFirstPtr);
 		Tcl_Free(defaultPtr->fileName);
-		Tcl_Free(defaultPtr->packageName);
+		Tcl_Free(defaultPtr->prefix);
 		Tcl_Free(defaultPtr);
 		Tcl_Free(ipPtr);
-		Tcl_MutexUnlock(&packageMutex);
+		Tcl_MutexUnlock(&libraryMutex);
 	    } else {
 		code = TCL_ERROR;
 	    }
@@ -920,7 +918,7 @@ Tcl_UnloadObjCmd(
 /*
  *----------------------------------------------------------------------
  *
- * Tcl_StaticPackage --
+ * Tcl_StaticLibrary --
  *
  *	This function is invoked to indicate that a particular package has
  *	been linked statically with an application.
@@ -936,14 +934,12 @@ Tcl_UnloadObjCmd(
  */
 
 void
-Tcl_StaticPackage(
+Tcl_StaticLibrary(
     Tcl_Interp *interp,		/* If not NULL, it means that the package has
 				 * already been loaded into the given
 				 * interpreter by calling the appropriate init
 				 * proc. */
-    const char *pkgName,	/* Name of package (must be properly
-				 * capitalized: first letter upper case,
-				 * others lower case). */
+    const char *prefix,	/* Prefix. */
     Tcl_PackageInitProc *initProc,
 				/* Function to call to incorporate this
 				 * package into a trusted interpreter. */
@@ -954,7 +950,7 @@ Tcl_StaticPackage(
 				 * the package can't be used in safe
 				 * interpreters. */
 {
-    LoadedPackage *pkgPtr;
+    LoadedLibrary *libraryPtr;
     InterpPackage *ipPtr, *ipFirstPtr;
 
     /*
@@ -962,34 +958,34 @@ Tcl_StaticPackage(
      * statically loaded in the process.
      */
 
-    Tcl_MutexLock(&packageMutex);
-    for (pkgPtr = firstPackagePtr; pkgPtr != NULL; pkgPtr = pkgPtr->nextPtr) {
-	if ((pkgPtr->initProc == initProc)
-		&& (pkgPtr->safeInitProc == safeInitProc)
-		&& (strcmp(pkgPtr->packageName, pkgName) == 0)) {
+    Tcl_MutexLock(&libraryMutex);
+    for (libraryPtr = firstLibraryPtr; libraryPtr != NULL; libraryPtr = libraryPtr->nextPtr) {
+	if ((libraryPtr->initProc == initProc)
+		&& (libraryPtr->safeInitProc == safeInitProc)
+		&& (strcmp(libraryPtr->prefix, prefix) == 0)) {
 	    break;
 	}
     }
-    Tcl_MutexUnlock(&packageMutex);
+    Tcl_MutexUnlock(&libraryMutex);
 
     /*
      * If the package is not yet recorded as being loaded statically, add it
      * to the list now.
      */
 
-    if (pkgPtr == NULL) {
-	pkgPtr = (LoadedPackage *)Tcl_Alloc(sizeof(LoadedPackage));
-	pkgPtr->fileName	= (char *)Tcl_Alloc(1);
-	pkgPtr->fileName[0]	= 0;
-	pkgPtr->packageName	= (char *)Tcl_Alloc(strlen(pkgName) + 1);
-	strcpy(pkgPtr->packageName, pkgName);
-	pkgPtr->loadHandle	= NULL;
-	pkgPtr->initProc	= initProc;
-	pkgPtr->safeInitProc	= safeInitProc;
-	Tcl_MutexLock(&packageMutex);
-	pkgPtr->nextPtr		= firstPackagePtr;
-	firstPackagePtr		= pkgPtr;
-	Tcl_MutexUnlock(&packageMutex);
+    if (libraryPtr == NULL) {
+	libraryPtr = (LoadedLibrary *)Tcl_Alloc(sizeof(LoadedLibrary));
+	libraryPtr->fileName	= (char *)Tcl_Alloc(1);
+	libraryPtr->fileName[0]	= 0;
+	libraryPtr->prefix	= (char *)Tcl_Alloc(strlen(prefix) + 1);
+	strcpy(libraryPtr->prefix, prefix);
+	libraryPtr->loadHandle	= NULL;
+	libraryPtr->initProc	= initProc;
+	libraryPtr->safeInitProc	= safeInitProc;
+	Tcl_MutexLock(&libraryMutex);
+	libraryPtr->nextPtr		= firstLibraryPtr;
+	firstLibraryPtr		= libraryPtr;
+	Tcl_MutexUnlock(&libraryMutex);
     }
 
     if (interp != NULL) {
@@ -1001,7 +997,7 @@ Tcl_StaticPackage(
 
 	ipFirstPtr = (InterpPackage *)Tcl_GetAssocData(interp, "tclLoad", NULL);
 	for (ipPtr = ipFirstPtr; ipPtr != NULL; ipPtr = ipPtr->nextPtr) {
-	    if (ipPtr->pkgPtr == pkgPtr) {
+	    if (ipPtr->libraryPtr == libraryPtr) {
 		return;
 	    }
 	}
@@ -1012,7 +1008,7 @@ Tcl_StaticPackage(
 	 */
 
 	ipPtr = (InterpPackage *)Tcl_Alloc(sizeof(InterpPackage));
-	ipPtr->pkgPtr = pkgPtr;
+	ipPtr->libraryPtr = libraryPtr;
 	ipPtr->nextPtr = ipFirstPtr;
 	Tcl_SetAssocData(interp, "tclLoad", LoadCleanupProc, ipPtr);
     }
@@ -1021,7 +1017,7 @@ Tcl_StaticPackage(
 /*
  *----------------------------------------------------------------------
  *
- * TclGetLoadedPackagesEx --
+ * TclGetLoadedLibraries --
  *
  *	This function returns information about all of the files that are
  *	loaded (either in a particular interpreter, or for all interpreters).
@@ -1040,33 +1036,33 @@ Tcl_StaticPackage(
  */
 
 int
-TclGetLoadedPackagesEx(
+TclGetLoadedLibraries(
     Tcl_Interp *interp,		/* Interpreter in which to return information
 				 * or error message. */
     const char *targetName,	/* Name of target interpreter or NULL. If
 				 * NULL, return info about all interps;
 				 * otherwise, just return info about this
 				 * interpreter. */
-    const char *packageName)	/* Package name or NULL. If NULL, return info
+    const char *prefix)	/* Package name or NULL. If NULL, return info
 				 * for all packages.
 				 */
 {
     Tcl_Interp *target;
-    LoadedPackage *pkgPtr;
+    LoadedLibrary *libraryPtr;
     InterpPackage *ipPtr;
     Tcl_Obj *resultObj, *pkgDesc[2];
 
     if (targetName == NULL) {
 	TclNewObj(resultObj);
-	Tcl_MutexLock(&packageMutex);
-	for (pkgPtr = firstPackagePtr; pkgPtr != NULL;
-		pkgPtr = pkgPtr->nextPtr) {
-	    pkgDesc[0] = Tcl_NewStringObj(pkgPtr->fileName, -1);
-	    pkgDesc[1] = Tcl_NewStringObj(pkgPtr->packageName, -1);
+	Tcl_MutexLock(&libraryMutex);
+	for (libraryPtr = firstLibraryPtr; libraryPtr != NULL;
+		libraryPtr = libraryPtr->nextPtr) {
+	    pkgDesc[0] = Tcl_NewStringObj(libraryPtr->fileName, -1);
+	    pkgDesc[1] = Tcl_NewStringObj(libraryPtr->prefix, -1);
 	    Tcl_ListObjAppendElement(NULL, resultObj,
 		    Tcl_NewListObj(2, pkgDesc));
 	}
-	Tcl_MutexUnlock(&packageMutex);
+	Tcl_MutexUnlock(&libraryMutex);
 	Tcl_SetObjResult(interp, resultObj);
 	return TCL_OK;
     }
@@ -1080,14 +1076,14 @@ TclGetLoadedPackagesEx(
     /*
      * Return information about all of the available packages.
      */
-    if (packageName) {
+    if (prefix) {
 	resultObj = NULL;
 
 	for (; ipPtr != NULL; ipPtr = ipPtr->nextPtr) {
-	    pkgPtr = ipPtr->pkgPtr;
+	    libraryPtr = ipPtr->libraryPtr;
 
-	    if (!strcmp(packageName, pkgPtr->packageName)) {
-		resultObj = Tcl_NewStringObj(pkgPtr->fileName, -1);
+	    if (!strcmp(prefix, libraryPtr->prefix)) {
+		resultObj = Tcl_NewStringObj(libraryPtr->fileName, -1);
 		break;
 	    }
 	}
@@ -1105,9 +1101,9 @@ TclGetLoadedPackagesEx(
 
     TclNewObj(resultObj);
     for (; ipPtr != NULL; ipPtr = ipPtr->nextPtr) {
-	pkgPtr = ipPtr->pkgPtr;
-	pkgDesc[0] = Tcl_NewStringObj(pkgPtr->fileName, -1);
-	pkgDesc[1] = Tcl_NewStringObj(pkgPtr->packageName, -1);
+	libraryPtr = ipPtr->libraryPtr;
+	pkgDesc[0] = Tcl_NewStringObj(libraryPtr->fileName, -1);
+	pkgDesc[1] = Tcl_NewStringObj(libraryPtr->prefix, -1);
 	Tcl_ListObjAppendElement(NULL, resultObj, Tcl_NewListObj(2, pkgDesc));
     }
     Tcl_SetObjResult(interp, resultObj);
@@ -1154,7 +1150,7 @@ LoadCleanupProc(
  * TclFinalizeLoad --
  *
  *	This function is invoked just before the application exits. It frees
- *	all of the LoadedPackage structures.
+ *	all of the LoadedLibrary structures.
  *
  * Results:
  *	None.
@@ -1168,18 +1164,18 @@ LoadCleanupProc(
 void
 TclFinalizeLoad(void)
 {
-    LoadedPackage *pkgPtr;
+    LoadedLibrary *libraryPtr;
 
     /*
      * No synchronization here because there should just be one thread alive
-     * at this point. Logically, packageMutex should be grabbed at this point,
+     * at this point. Logically, libraryMutex should be grabbed at this point,
      * but the Mutexes get finalized before the call to this routine. The only
      * subsystem left alive at this point is the memory allocator.
      */
 
-    while (firstPackagePtr != NULL) {
-	pkgPtr = firstPackagePtr;
-	firstPackagePtr = pkgPtr->nextPtr;
+    while (firstLibraryPtr != NULL) {
+	libraryPtr = firstLibraryPtr;
+	firstLibraryPtr = libraryPtr->nextPtr;
 
 #if defined(TCL_UNLOAD_DLLS) || defined(_WIN32)
 	/*
@@ -1189,14 +1185,14 @@ TclFinalizeLoad(void)
 	 * it has been unloaded.
 	 */
 
-	if (pkgPtr->fileName[0] != '\0') {
-	    Tcl_FSUnloadFile(NULL, pkgPtr->loadHandle);
+	if (libraryPtr->fileName[0] != '\0') {
+	    Tcl_FSUnloadFile(NULL, libraryPtr->loadHandle);
 	}
 #endif
 
-	Tcl_Free(pkgPtr->fileName);
-	Tcl_Free(pkgPtr->packageName);
-	Tcl_Free(pkgPtr);
+	Tcl_Free(libraryPtr->fileName);
+	Tcl_Free(libraryPtr->prefix);
+	Tcl_Free(libraryPtr);
     }
 }
 
diff --git a/generic/tclStubInit.c b/generic/tclStubInit.c
index 93529d1..12e0272 100644
--- a/generic/tclStubInit.c
+++ b/generic/tclStubInit.c
@@ -60,9 +60,9 @@
 #undef TclWinGetSockOpt
 #undef TclWinSetSockOpt
 #undef TclWinNToHS
-#undef TclStaticPackage
+#undef TclStaticLibrary
 #undef Tcl_BackgroundError
-#define TclStaticPackage Tcl_StaticPackage
+#define TclStaticLibrary Tcl_StaticLibrary
 #undef Tcl_UniCharToUtfDString
 #undef Tcl_UtfToUniCharDString
 #undef Tcl_UtfToUniChar
@@ -528,7 +528,7 @@ static const TclIntStubs tclIntStubs = {
     TclPtrIncrObjVar, /* 254 */
     TclPtrObjMakeUpvar, /* 255 */
     TclPtrUnsetVar, /* 256 */
-    TclStaticPackage, /* 257 */
+    TclStaticLibrary, /* 257 */
     TclpCreateTemporaryDirectory, /* 258 */
     TclAppendUnicodeToObj, /* 259 */
     TclGetBytesFromObj, /* 260 */
diff --git a/macosx/Tcl.xcode/project.pbxproj b/macosx/Tcl.xcode/project.pbxproj
index 8004ffe..6a3b921 100644
--- a/macosx/Tcl.xcode/project.pbxproj
+++ b/macosx/Tcl.xcode/project.pbxproj
@@ -394,7 +394,7 @@
 		F96D3EA208F272A7004A47F5 /* split.n */ = {isa = PBXFileReference; explicitFileType = text.man; fileEncoding = 4; path = split.n; sourceTree = "<group>"; };
 		F96D3EA308F272A7004A47F5 /* SplitList.3 */ = {isa = PBXFileReference; explicitFileType = text.man; fileEncoding = 4; path = SplitList.3; sourceTree = "<group>"; };
 		F96D3EA408F272A7004A47F5 /* SplitPath.3 */ = {isa = PBXFileReference; explicitFileType = text.man; fileEncoding = 4; path = SplitPath.3; sourceTree = "<group>"; };
-		F96D3EA508F272A7004A47F5 /* StaticPkg.3 */ = {isa = PBXFileReference; explicitFileType = text.man; fileEncoding = 4; path = StaticPkg.3; sourceTree = "<group>"; };
+		F96D3EA508F272A7004A47F5 /* StaticLibrary.3 */ = {isa = PBXFileReference; explicitFileType = text.man; fileEncoding = 4; path = StaticLibrary.3; sourceTree = "<group>"; };
 		F96D3EA608F272A7004A47F5 /* StdChannels.3 */ = {isa = PBXFileReference; explicitFileType = text.man; fileEncoding = 4; path = StdChannels.3; sourceTree = "<group>"; };
 		F96D3EA708F272A7004A47F5 /* string.n */ = {isa = PBXFileReference; explicitFileType = text.man; fileEncoding = 4; path = string.n; sourceTree = "<group>"; };
 		F96D3EA808F272A7004A47F5 /* StringObj.3 */ = {isa = PBXFileReference; explicitFileType = text.man; fileEncoding = 4; path = StringObj.3; sourceTree = "<group>"; };
@@ -1149,7 +1149,7 @@
 				F96D3EA208F272A7004A47F5 /* split.n */,
 				F96D3EA308F272A7004A47F5 /* SplitList.3 */,
 				F96D3EA408F272A7004A47F5 /* SplitPath.3 */,
-				F96D3EA508F272A7004A47F5 /* StaticPkg.3 */,
+				F96D3EA508F272A7004A47F5 /* StaticLibrary.3 */,
 				F96D3EA608F272A7004A47F5 /* StdChannels.3 */,
 				F96D3EA708F272A7004A47F5 /* string.n */,
 				F96D3EA808F272A7004A47F5 /* StringObj.3 */,
diff --git a/macosx/Tcl.xcodeproj/project.pbxproj b/macosx/Tcl.xcodeproj/project.pbxproj
index 6528616..47f522c 100644
--- a/macosx/Tcl.xcodeproj/project.pbxproj
+++ b/macosx/Tcl.xcodeproj/project.pbxproj
@@ -393,7 +393,7 @@
 		F96D3EA208F272A7004A47F5 /* split.n */ = {isa = PBXFileReference; explicitFileType = text.man; fileEncoding = 4; path = split.n; sourceTree = "<group>"; };
 		F96D3EA308F272A7004A47F5 /* SplitList.3 */ = {isa = PBXFileReference; explicitFileType = text.man; fileEncoding = 4; path = SplitList.3; sourceTree = "<group>"; };
 		F96D3EA408F272A7004A47F5 /* SplitPath.3 */ = {isa = PBXFileReference; explicitFileType = text.man; fileEncoding = 4; path = SplitPath.3; sourceTree = "<group>"; };
-		F96D3EA508F272A7004A47F5 /* StaticPkg.3 */ = {isa = PBXFileReference; explicitFileType = text.man; fileEncoding = 4; path = StaticPkg.3; sourceTree = "<group>"; };
+		F96D3EA508F272A7004A47F5 /* StaticLibrary.3 */ = {isa = PBXFileReference; explicitFileType = text.man; fileEncoding = 4; path = StaticLibrary.3; sourceTree = "<group>"; };
 		F96D3EA608F272A7004A47F5 /* StdChannels.3 */ = {isa = PBXFileReference; explicitFileType = text.man; fileEncoding = 4; path = StdChannels.3; sourceTree = "<group>"; };
 		F96D3EA708F272A7004A47F5 /* string.n */ = {isa = PBXFileReference; explicitFileType = text.man; fileEncoding = 4; path = string.n; sourceTree = "<group>"; };
 		F96D3EA808F272A7004A47F5 /* StringObj.3 */ = {isa = PBXFileReference; explicitFileType = text.man; fileEncoding = 4; path = StringObj.3; sourceTree = "<group>"; };
@@ -1149,7 +1149,7 @@
 				F96D3EA208F272A7004A47F5 /* split.n */,
 				F96D3EA308F272A7004A47F5 /* SplitList.3 */,
 				F96D3EA408F272A7004A47F5 /* SplitPath.3 */,
-				F96D3EA508F272A7004A47F5 /* StaticPkg.3 */,
+				F96D3EA508F272A7004A47F5 /* StaticLibrary.3 */,
 				F96D3EA608F272A7004A47F5 /* StdChannels.3 */,
 				F96D3EA708F272A7004A47F5 /* string.n */,
 				F96D3EA808F272A7004A47F5 /* StringObj.3 */,
diff --git a/tests/load.test b/tests/load.test
index c79ddf4..eaaf7a7 100644
--- a/tests/load.test
+++ b/tests/load.test
@@ -36,9 +36,9 @@ testConstraint $loaded [expr {![string match *pkga* $alreadyLoaded]}]
 
 set alreadyTotalLoaded [info loaded]
 
-# Certain tests require the 'teststaticpkg' command from tcltest
+# Certain tests require the 'teststaticlibrary' command from tcltest
 
-testConstraint teststaticpkg [llength [info commands teststaticpkg]]
+testConstraint teststaticlibrary [llength [info commands teststaticlibrary]]
 
 # Test load-10.1 requires the 'testsimplefilesystem' command from tcltest
 
@@ -47,10 +47,10 @@ testConstraint testsimplefilesystem \
 
 test load-1.1 {basic errors} -returnCodes error -body {
     load
-} -result {wrong # args: should be "load ?-global? ?-lazy? ?--? fileName ?packageName? ?interp?"}
+} -result {wrong # args: should be "load ?-global? ?-lazy? ?--? fileName ?prefix? ?interp?"}
 test load-1.2 {basic errors} -returnCodes error -body {
     load a b c d
-} -result {wrong # args: should be "load ?-global? ?-lazy? ?--? fileName ?packageName? ?interp?"}
+} -result {wrong # args: should be "load ?-global? ?-lazy? ?--? fileName ?prefix? ?interp?"}
 test load-1.3 {basic errors} -returnCodes error -body {
     load a b foobar
 } -result {could not find interpreter "foobar"}
@@ -62,7 +62,7 @@ test load-1.5 {basic errors} -returnCodes error -body {
 } -result {must specify either file name or package name}
 test load-1.6 {basic errors} -returnCodes error -body {
     load {} Unknown
-} -result {package "Unknown" isn't loaded statically}
+} -result {no library with prefix "Unknown" is loaded statically}
 test load-1.7 {basic errors} -returnCodes error -body {
     load -abc foo
 } -result {bad option "-abc": must be -global, -lazy, or --}
@@ -78,13 +78,13 @@ test load-2.1 {basic loading, with guess for package name} \
 interp create -safe child
 test load-2.2 {loading into a safe interpreter, with package name conversion} \
 	[list $dll $loaded] {
-    load -lazy [file join $testDir pkgb$ext] pKgB child
+    load -lazy [file join $testDir pkgb$ext] Pkgb child
     list [child eval pkgb_sub 44 13] [catch {child eval pkgb_unsafe} msg] $msg \
 	    [catch {pkgb_sub 12 10} msg2] $msg2
 } {31 1 {invalid command name "pkgb_unsafe"} 1 {invalid command name "pkgb_sub"}}
 test load-2.3 {loading with no _Init procedure} -constraints [list $dll $loaded] \
 -body {
-    list [catch {load [file join $testDir pkgc$ext] foo} msg] $msg $errorCode
+    list [catch {load [file join $testDir pkgc$ext] Foo} msg] $msg $errorCode
 } -match glob \
     -result [list 1 {cannot find symbol "Foo_Init"*} \
 		 {TCL LOOKUP LOAD_SYMBOL *Foo_Init}]
@@ -94,7 +94,7 @@ test load-2.4 {loading with no _SafeInit procedure} [list $dll $loaded] {
 
 test load-3.1 {error in _Init procedure, same interpreter} \
 	[list $dll $loaded] {
-    list [catch {load [file join $testDir pkge$ext] pkge} msg] \
+    list [catch {load [file join $testDir pkge$ext] Pkge} msg] \
 	    $msg $::errorInfo $::errorCode
 } {1 {couldn't open "non_existent": no such file or directory} {couldn't open "non_existent": no such file or directory
     while executing
@@ -102,14 +102,14 @@ test load-3.1 {error in _Init procedure, same interpreter} \
     invoked from within
 "if 44 {open non_existent}"
     invoked from within
-"load [file join $testDir pkge$ext] pkge"} {POSIX ENOENT {no such file or directory}}}
+"load [file join $testDir pkge$ext] Pkge"} {POSIX ENOENT {no such file or directory}}}
 test load-3.2 {error in _Init procedure, child interpreter} \
 	[list $dll $loaded] {
     catch {interp delete x}
     interp create x
     set ::errorCode foo
     set ::errorInfo bar
-    set result [list [catch {load [file join $testDir pkge$ext] pkge x} msg] \
+    set result [list [catch {load [file join $testDir pkge$ext] Pkge x} msg] \
 	    $msg $::errorInfo $::errorCode]
     interp delete x
     set result
@@ -119,23 +119,23 @@ test load-3.2 {error in _Init procedure, child interpreter} \
     invoked from within
 "if 44 {open non_existent}"
     invoked from within
-"load [file join $testDir pkge$ext] pkge x"} {POSIX ENOENT {no such file or directory}}}
+"load [file join $testDir pkge$ext] Pkge x"} {POSIX ENOENT {no such file or directory}}}
 
 test load-4.1 {reloading package into same interpreter} [list $dll $loaded] {
-    list [catch {load [file join $testDir pkga$ext] pkga} msg] $msg
+    list [catch {load [file join $testDir pkga$ext] Pkga} msg] $msg
 } {0 {}}
 test load-4.2 {reloading package into same interpreter} -setup {
     catch {load [file join $testDir pkga$ext] pkga}
 } -constraints [list $dll $loaded] -returnCodes error -body {
-    load [file join $testDir pkga$ext] pkgb
+    load [file join $testDir pkga$ext] Pkgb
 } -result "file \"[file join $testDir pkga$ext]\" is already loaded for package \"Pkga\""
 
 test load-5.1 {file name not specified and no static package: pick default} -setup {
     catch {interp delete x}
     interp create x
 } -constraints [list $dll $loaded] -body {
-    load -global [file join $testDir pkga$ext] pkga
-    load {} pkga x
+    load -global [file join $testDir pkga$ext] Pkga
+    load {} Pkga x
     info loaded x
 } -cleanup {
     interp delete x
@@ -150,78 +150,78 @@ test load-6.1 {errors loading file} [list $dll $loaded] {
     catch {load foo foo}
 } {1}
 
-test load-7.1 {Tcl_StaticPackage procedure} [list teststaticpkg] {
+test load-7.1 {Tcl_StaticLibrary procedure} [list teststaticlibrary] {
     set x "not loaded"
-    teststaticpkg Test 1 0
+    teststaticlibrary Test 1 0
     load {} Test
     load {} Test child
     list [set x] [child eval set x]
 } {loaded loaded}
-test load-7.2 {Tcl_StaticPackage procedure} [list teststaticpkg] {
+test load-7.2 {Tcl_StaticLibrary procedure} [list teststaticlibrary] {
     set x "not loaded"
-    teststaticpkg Another 0 0
+    teststaticlibrary Another 0 0
     load {} Another
     child eval {set x "not loaded"}
     list [catch {load {} Another child} msg] $msg \
 	[child eval set x] [set x]
 } {1 {can't use package in a safe interpreter: no Another_SafeInit procedure} {not loaded} loaded}
-test load-7.3 {Tcl_StaticPackage procedure} [list teststaticpkg] {
+test load-7.3 {Tcl_StaticLibrary procedure} [list teststaticlibrary] {
     set x "not loaded"
-    teststaticpkg More 0 1
+    teststaticlibrary More 0 1
     load {} More
     set x
 } {not loaded}
-catch {load [file join $testDir pkga$ext] pkga}
-catch {load [file join $testDir pkgb$ext] pkgb}
-catch {load [file join $testDir pkge$ext] pkge}
+catch {load [file join $testDir pkga$ext] Pkga}
+catch {load [file join $testDir pkgb$ext] Pkgb}
+catch {load [file join $testDir pkge$ext] Pkge}
 set currentRealPackages [list [list [file join $testDir pkge$ext] Pkge] [list [file join $testDir pkgb$ext] Pkgb] [list [file join $testDir pkga$ext] Pkga]]
-test load-7.4 {Tcl_StaticPackage procedure, redundant calls} -setup {
-    teststaticpkg Test 1 0
-    teststaticpkg Another 0 0
-    teststaticpkg More 0 1
-} -constraints [list teststaticpkg $dll $loaded] -body {
-    teststaticpkg Double 0 1
-    teststaticpkg Double 0 1
+test load-7.4 {Tcl_StaticLibrary procedure, redundant calls} -setup {
+    teststaticlibrary Test 1 0
+    teststaticlibrary Another 0 0
+    teststaticlibrary More 0 1
+} -constraints [list teststaticlibrary $dll $loaded] -body {
+    teststaticlibrary Double 0 1
+    teststaticlibrary Double 0 1
     info loaded
 } -result [list {{} Double} {{} More} {{} Another} {{} Test} {*}$currentRealPackages {*}$alreadyTotalLoaded]
 
-testConstraint teststaticpkg_8.x 0
-if {[testConstraint teststaticpkg]} {
+testConstraint teststaticlibrary_8.x 0
+if {[testConstraint teststaticlibrary]} {
     catch {
-	teststaticpkg Test 1 1
-	teststaticpkg Another 0 1
-	teststaticpkg More 0 1
-	teststaticpkg Double 0 1
-	testConstraint teststaticpkg_8.x 1
+	teststaticlibrary Test 1 1
+	teststaticlibrary Another 0 1
+	teststaticlibrary More 0 1
+	teststaticlibrary Double 0 1
+	testConstraint teststaticlibrary_8.x 1
     }
 }
 
-test load-8.1 {TclGetLoadedPackages procedure} [list teststaticpkg_8.x $dll $loaded] {
+test load-8.1 {TclGetLoadedPackages procedure} [list teststaticlibrary_8.x $dll $loaded] {
     lsort -index 1 [info loaded]
 } [lsort -index 1 [list {{} Double} {{} More} {{} Another} {{} Test} {*}$currentRealPackages {*}$alreadyTotalLoaded]]
-test load-8.2 {TclGetLoadedPackages procedure} -constraints {teststaticpkg_8.x} -body {
+test load-8.2 {TclGetLoadedPackages procedure} -constraints {teststaticlibrary_8.x} -body {
     info loaded gorp
 } -returnCodes error -result {could not find interpreter "gorp"}
-test load-8.3a {TclGetLoadedPackages procedure} [list teststaticpkg_8.x $dll $loaded] {
+test load-8.3a {TclGetLoadedPackages procedure} [list teststaticlibrary_8.x $dll $loaded] {
     lsort -index 1 [info loaded {}]
 } [lsort -index 1 [list {{} Double} {{} More} {{} Another} {{} Test} [list [file join $testDir pkga$ext] Pkga] [list [file join $testDir pkgb$ext] Pkgb] {*}$alreadyLoaded]]
-test load-8.3b {TclGetLoadedPackages procedure} [list teststaticpkg_8.x $dll $loaded] {
+test load-8.3b {TclGetLoadedPackages procedure} [list teststaticlibrary_8.x $dll $loaded] {
     lsort -index 1 [info loaded child]
 } [lsort -index 1 [list {{} Test} [list [file join $testDir pkgb$ext] Pkgb]]]
-test load-8.4 {TclGetLoadedPackages procedure} [list teststaticpkg_8.x $dll $loaded] {
-    load [file join $testDir pkgb$ext] pkgb
+test load-8.4 {TclGetLoadedPackages procedure} [list teststaticlibrary_8.x $dll $loaded] {
+    load [file join $testDir pkgb$ext] Pkgb
     list [lsort -index 1 [info loaded {}]] [lsort [info commands pkgb_*]]
 } [list [lsort -index 1 [concat [list [list [file join $testDir pkgb$ext] Pkgb] {{} Double} {{} More} {{} Another} {{} Test} [list [file join $testDir pkga$ext] Pkga]] $alreadyLoaded]] {pkgb_demo pkgb_sub pkgb_unsafe}]
 interp delete child
 
-test load-9.1 {Tcl_StaticPackage, load already-loaded package into another interp} -setup {
+test load-9.1 {Tcl_StaticLibrary, load already-loaded package into another interp} -setup {
     interp create child1
     interp create child2
     load {} Tcltest child1
     load {} Tcltest child2
-} -constraints {teststaticpkg} -body {
-    child1 eval { teststaticpkg Loadninepointone 0 1 }
-    child2 eval { teststaticpkg Loadninepointone 0 1 }
+} -constraints {teststaticlibrary} -body {
+    child1 eval { teststaticlibrary Loadninepointone 0 1 }
+    child2 eval { teststaticlibrary Loadninepointone 0 1 }
     list [child1 eval { info loaded {} }] \
 	[child2 eval { info loaded {} }]
 } -match glob -cleanup {
@@ -234,7 +234,7 @@ test load-10.1 {load from vfs} -setup {
     cd $testDir
     testsimplefilesystem 1
 } -constraints [list $dll $loaded testsimplefilesystem] -body {
-    list [catch {load simplefs:/pkgd$ext pkgd} msg] $msg
+    list [catch {load simplefs:/pkgd$ext Pkgd} msg] $msg
 } -result {0 {}} -cleanup {
     testsimplefilesystem 0
     cd $dir
diff --git a/tests/safe.test b/tests/safe.test
index 1177e19..0394eb9 100644
--- a/tests/safe.test
+++ b/tests/safe.test
@@ -1157,7 +1157,7 @@ test safe-9.24 {interpConfigure change the access path; check module loading; st
         res0 res1 res2}
 # See comments on lsort after test safe-9.20.
 
-catch {teststaticpkg Safepkg1 0 0}
+catch {teststaticlibrary Safepkg1 0 0}
 test safe-10.1 {testing statics loading} -constraints TcltestPackage -setup {
     set i [safe::interpCreate]
 } -body {
diff --git a/tests/unload.test b/tests/unload.test
index 32767fa..f1f4580 100644
--- a/tests/unload.test
+++ b/tests/unload.test
@@ -53,10 +53,10 @@ proc loadIfNotPresent {pkg args} {
 # Basic tests: parameter testing...
 test unload-1.1 {basic errors} -returnCodes error -body {
     unload
-} -result {wrong # args: should be "unload ?-switch ...? fileName ?packageName? ?interp?"}
+} -result {wrong # args: should be "unload ?-switch ...? fileName ?prefix? ?interp?"}
 test unload-1.2 {basic errors} -returnCodes error -body {
     unload a b c d
-} -result {wrong # args: should be "unload ?-switch ...? fileName ?packageName? ?interp?"}
+} -result {wrong # args: should be "unload ?-switch ...? fileName ?prefix? ?interp?"}
 test unload-1.3 {basic errors} -returnCodes error -body {
     unload a b foobar
 } -result {could not find interpreter "foobar"}
@@ -68,7 +68,7 @@ test unload-1.5 {basic errors} -returnCodes error -body {
 } -result {must specify either file name or package name}
 test unload-1.6 {basic errors} -returnCodes error -body {
     unload {} Unknown
-} -result {package "Unknown" is loaded statically and cannot be unloaded}
+} -result {library with prefix "Unknown" is loaded statically and cannot be unloaded}
 test unload-1.7 {-nocomplain switch} {
     unload -nocomplain {} Unknown
 } {}
@@ -135,14 +135,14 @@ child eval {
 test unload-3.1 {basic loading of non-unloadable package in a safe interpreter, with package name conversion} \
 	[list $dll $loaded] {
     catch {rename pkgb_sub {}}
-    load [file join $testDir pkgb$ext] pKgB child
+    load [file join $testDir pkgb$ext] Pkgb child
     list [child eval pkgb_sub 44 13] [catch {child eval pkgb_unsafe} msg] $msg \
          [catch {pkgb_sub 12 10} msg2] $msg2
 } {31 1 {invalid command name "pkgb_unsafe"} 1 {invalid command name "pkgb_sub"}}
 test unload-3.2 {basic loading of unloadable package in a safe interpreter, with package name conversion} \
 	[list $dll $loaded] {
     list [child eval {list $pkgua_loaded $pkgua_detached $pkgua_unloaded}] \
-	    [load [file join $testDir pkgua$ext] pKgUA child] \
+	    [load [file join $testDir pkgua$ext] Pkgua child] \
 	    [child eval pkgua_eq abc def] \
 	    [lsort [child eval info commands pkgua_*]] \
 	    [child eval {list $pkgua_loaded $pkgua_detached $pkgua_unloaded}]
@@ -154,14 +154,14 @@ test unload-3.3 {unloading of a package that has never been loaded from a safe i
 } -result {file "*" has never been loaded in this interpreter}
 test unload-3.4 {basic unloading of a non-unloadable package from a safe interpreter, with guess for package name} -setup {
     if {[lsearch -index 1 [info loaded child] Pkgb] < 0} {
-	load [file join $testDir pkgb$ext] pKgB child
+	load [file join $testDir pkgb$ext] Pkgb child
     }
 } -constraints [list $dll $loaded] -returnCodes error -match glob -body {
     unload [file join $testDir pkgb$ext] {} child
 } -result {file "*" cannot be unloaded under a safe interpreter}
 test unload-3.5 {basic unloading of an unloadable package from a safe interpreter, with guess for package name} -setup {
     if {[lsearch -index 1 [info loaded child] Pkgua] < 0} {
-	load [file join $testDir pkgua$ext] pkgua child
+	load [file join $testDir pkgua$ext] Pkgua child
     }
 } -constraints [list $dll $loaded] -body {
     list [child eval {list $pkgua_loaded $pkgua_detached $pkgua_unloaded}] \
@@ -189,7 +189,7 @@ test unload-3.7 {basic unloading of re-loaded package from a safe interpreter, w
     }
 } -constraints [list $dll $loaded] -body {
     list [child eval {list $pkgua_loaded $pkgua_detached $pkgua_unloaded}] \
-	    [unload [file join $testDir pkgua$ext] pKgUa child] \
+	    [unload [file join $testDir pkgua$ext] Pkgua child] \
 	    [child eval info commands pkgua_*] \
 	    [child eval {list $pkgua_loaded $pkgua_detached $pkgua_unloaded}]
 } -result {{.. . .} {} {} {.. .. ..}}
@@ -224,7 +224,7 @@ test unload-4.2 {basic loading of unloadable package in a safe interpreter, with
     incr load(C)
 } -constraints [list $dll $loaded] -body {
     list [child eval {list $pkgua_loaded $pkgua_detached $pkgua_unloaded}] \
-	    [load [file join $testDir pkgua$ext] pKgUA child] \
+	    [load [file join $testDir pkgua$ext] Pkgua child] \
 	    [child eval pkgua_eq abc def] \
 	    [lsort [child eval info commands pkgua_*]] \
 	    [child eval {list $pkgua_loaded $pkgua_detached $pkgua_unloaded}]
@@ -234,7 +234,7 @@ test unload-4.3 {basic loading of unloadable package in a second trusted interpr
     incr load(T)
 } -constraints [list $dll $loaded] -body {
     list [child-trusted eval {list $pkgua_loaded $pkgua_detached $pkgua_unloaded}] \
-	    [load [file join $testDir pkgua$ext] pkguA child-trusted] \
+	    [load [file join $testDir pkgua$ext] Pkgua child-trusted] \
 	    [child-trusted eval pkgua_eq abc def] \
 	    [lsort [child-trusted eval info commands pkgua_*]] \
 	    [child-trusted eval {list $pkgua_loaded $pkgua_detached $pkgua_unloaded}]
@@ -291,7 +291,7 @@ test unload-5.1 {unload a module loaded from vfs} \
 	 set dir [pwd]
 	 cd $testDir
 	 testsimplefilesystem 1
-	 load simplefs:/pkgua$ext pkgua
+	 load simplefs:/pkgua$ext Pkgua
      } \
     -body {
 	list [catch {unload simplefs:/pkgua$ext} msg] $msg
diff --git a/unix/tclAppInit.c b/unix/tclAppInit.c
index 3587f35..0b03d5d 100644
--- a/unix/tclAppInit.c
+++ b/unix/tclAppInit.c
@@ -124,7 +124,7 @@ Tcl_AppInit(
     if (Tcltest_Init(interp) == TCL_ERROR) {
 	return TCL_ERROR;
     }
-    Tcl_StaticPackage(interp, "Tcltest", Tcltest_Init, Tcltest_SafeInit);
+    Tcl_StaticLibrary(interp, "Tcltest", Tcltest_Init, Tcltest_SafeInit);
 #endif /* TCL_TEST */
 
     /*
diff --git a/win/tcl.dsp b/win/tcl.dsp
index 8b20d66..02dcf32 100644
--- a/win/tcl.dsp
+++ b/win/tcl.dsp
@@ -824,7 +824,7 @@ SOURCE=..\doc\SplitPath.3
 # End Source File
 # Begin Source File
 
-SOURCE=..\doc\StaticPkg.3
+SOURCE=..\doc\StaticLibrary.3
 # End Source File
 # Begin Source File
 
diff --git a/win/tclAppInit.c b/win/tclAppInit.c
index a9fb3bd..5c479f9 100644
--- a/win/tclAppInit.c
+++ b/win/tclAppInit.c
@@ -168,19 +168,19 @@ Tcl_AppInit(
     if (Registry_Init(interp) == TCL_ERROR) {
 	return TCL_ERROR;
     }
-    Tcl_StaticPackage(interp, "Registry", Registry_Init, NULL);
+    Tcl_StaticLibrary(interp, "Registry", Registry_Init, NULL);
 
     if (Dde_Init(interp) == TCL_ERROR) {
 	return TCL_ERROR;
     }
-    Tcl_StaticPackage(interp, "Dde", Dde_Init, Dde_SafeInit);
+    Tcl_StaticLibrary(interp, "Dde", Dde_Init, Dde_SafeInit);
 #endif
 
 #ifdef TCL_TEST
     if (Tcltest_Init(interp) == TCL_ERROR) {
 	return TCL_ERROR;
     }
-    Tcl_StaticPackage(interp, "Tcltest", Tcltest_Init, Tcltest_SafeInit);
+    Tcl_StaticLibrary(interp, "Tcltest", Tcltest_Init, Tcltest_SafeInit);
 #endif /* TCL_TEST */
 
     /*
diff --git a/generic/tclTest.c b/generic/tclTest.c
index 91e3b49..502d9c9 100644
--- a/generic/tclTest.c
+++ b/generic/tclTest.c
@@ -274,7 +274,7 @@ static Tcl_CmdProc	Testset2Cmd;
 static Tcl_CmdProc	TestseterrorcodeCmd;
 static Tcl_ObjCmdProc	TestsetobjerrorcodeCmd;
 static Tcl_CmdProc	TestsetplatformCmd;
-static Tcl_CmdProc	TeststaticpkgCmd;
+static Tcl_CmdProc	TeststaticlibraryCmd;
 static Tcl_CmdProc	TesttranslatefilenameCmd;
 static Tcl_CmdProc	TestupvarCmd;
 static Tcl_ObjCmdProc	TestWrongNumArgsObjCmd;
@@ -601,7 +601,7 @@ Tcltest_Init(
 	    NULL, NULL);
     Tcl_CreateCommand(interp, "testsocket", TestSocketCmd,
 	    NULL, NULL);
-    Tcl_CreateCommand(interp, "teststaticpkg", TeststaticpkgCmd,
+    Tcl_CreateCommand(interp, "teststaticlibrary", TeststaticlibraryCmd,
 	    NULL, NULL);
     Tcl_CreateCommand(interp, "testtranslatefilename",
 	    TesttranslatefilenameCmd, NULL, NULL);
@@ -4217,10 +4217,10 @@ TestsetplatformCmd(
 /*
  *----------------------------------------------------------------------
  *
- * TeststaticpkgCmd --
+ * TeststaticlibraryCmd --
  *
  *	This procedure implements the "teststaticpkg" command.
  *	It is used to test the procedure Tcl_StaticPackage.
  *
  * Results:
  *	A standard Tcl result.
@@ -4233,7 +4233,7 @@ TestsetplatformCmd(
  */
 
 static int
-TeststaticpkgCmd(
+TeststaticlibraryCmd(
     TCL_UNUSED(void *),
     Tcl_Interp *interp,		/* Current interpreter. */
     int argc,			/* Number of arguments. */
@@ -4243,7 +4243,7 @@ TeststaticpkgCmd(
 
     if (argc != 4) {
 	Tcl_AppendResult(interp, "wrong # arguments: should be \"",
-		argv[0], " pkgName safe loaded\"", NULL);
+		argv[0], " prefix safe loaded\"", NULL);
 	return TCL_ERROR;
     }
     if (Tcl_GetInt(interp, argv[2], &safe) != TCL_OK) {
@@ -4252,7 +4252,7 @@ TeststaticpkgCmd(
     if (Tcl_GetInt(interp, argv[3], &loaded) != TCL_OK) {
 	return TCL_ERROR;
     }
-    Tcl_StaticPackage((loaded) ? interp : NULL, argv[1],
+    Tcl_StaticLibrary((loaded) ? interp : NULL, argv[1],
 	    StaticInitProc, (safe) ? StaticInitProc : NULL);
     return TCL_OK;
 }
@@ -4217,10 +4217,10 @@ TestsetplatformCmd(
  *
- *	This procedure implements the "teststaticpkg" command.
- *	It is used to test the procedure Tcl_StaticPackage.
+ *	This procedure implements the "teststaticlibrary" command.
+ *	It is used to test the procedure Tcl_StaticLibrary.
  *
  * Results:
-- 
cgit v0.12